import { Component, Input, ViewChild, NgModule } from '@angular/core';
import { Chart } from 'chart.js';
import randomColor from 'randomcolor';
import 'rxjs';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChartJsComponent {
    constructor() {
        this.chartData = [];
        this.chart = null;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set data(value) {
        this.chartData = value;
        this.updateData();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.ctx = this.canvasRef.nativeElement.getContext('2d');
        switch (this.type) {
            case 'chart.pie': {
                this.createChartPie();
                break;
            }
            case 'chart.bar': {
                this.createChartBar();
                break;
            }
            case 'chart.column': {
                this.createChartColumn();
                break;
            }
            default: {
                console.warn('Chart couldn\'t be generated');
                break;
            }
        }
        this.updateChart.subscribe((/**
         * @return {?}
         */
        () => {
            this.updateData();
        }));
    }
    /**
     * @return {?}
     */
    createChartPie() {
        this.chart = new Chart(this.ctx, {
            type: 'pie',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    }
    /**
     * @return {?}
     */
    createChartBar() {
        this.chart = new Chart(this.ctx, {
            type: 'horizontalBar',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    }
    /**
     * @return {?}
     */
    createChartColumn() {
        this.chart = new Chart(this.ctx, {
            type: 'bar',
            data: {
                labels: this.chartData.labels,
                datasets: [{
                        label: this.chartData.series,
                        data: this.chartData.data,
                        backgroundColor: this.dynamicColors(),
                    }]
            },
            responsive: true,
            maintainAspectRatio: false
        });
    }
    /**
     * @return {?}
     */
    dynamicColors() {
        /** @type {?} */
        const color = randomColor({
            count: this.chartData.data.length + 1,
            format: 'rgb',
            luminosity: 'light',
            hue: 'random',
        });
        return color;
    }
    /**
     * @return {?}
     */
    updateData() {
        if (this.chart) {
            this.chart.data.labels = this.chartData.labels ? this.chartData.labels : [];
            this.chart.data.datasets = [{
                    label: this.chartData.series ? this.chartData.series : null,
                    data: this.chartData.data ? this.chartData.data : [],
                    backgroundColor: this.dynamicColors(),
                }];
            this.chart.update();
        }
    }
}
ChartJsComponent.decorators = [
    { type: Component, args: [{
                selector: 'chartjs-chart',
                template: "<div class=\"chart-container\">\n    <canvas #canvas>{{chart}}</canvas>\n</div>\n",
                styles: [".chart-container{max-width:100%!important;overflow-y:auto}.chart-container canvas{max-height:100%;max-width:100%}"]
            }] }
];
/** @nocollapse */
ChartJsComponent.ctorParameters = () => [];
ChartJsComponent.propDecorators = {
    type: [{ type: Input }],
    data: [{ type: Input }],
    label: [{ type: Input }],
    updateChart: [{ type: Input }],
    canvasRef: [{ type: ViewChild, args: ['canvas',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChartJsModule {
}
ChartJsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    ChartJsComponent
                ],
                providers: [],
                exports: [
                    ChartJsComponent
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ChartJsModule, ChartJsComponent };

//# sourceMappingURL=biosoftcl-chart-js-module.js.map